pkmn-colosseum decompilation progress · ByteMatchpkmn-colosseum is 15.35% decompiled
0.00% fully linked · GameCube
Code (2.50 MB)
Matched15.35% · 382,876 of 2,495,108 bytes (382.88 KB)Fuzzy match31.36% · ≈782,588 of 2,495,108 bytes (782.59 KB), counting partly matched code Fully linked 0.00%
Fully linked
0.00% · 0 of 2,495,108 bytes (0 B)
Matched 15.35%Matched15.35% · 382,876 of 2,495,108 bytes (382.88 KB)
Fuzzy match 31.36%Fuzzy match31.36% · ≈782,588 of 2,495,108 bytes (782.59 KB), counting partly matched code
Data (2.20 MB)
Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB) Fully linked 0.00%Fully linked0.00% · 0 of 2,196,256 bytes (0 B)Matched 0.77%Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB)
eaf5f2f | README: progress update
· No unit breakdown is stored for this commit (it came from decomp.dev's history, which keeps totals only).
Merge pull request #664: verified 97.44 percent source data